"""CoT (Chain-of-Thought) acceleration module (Task3.5)."""

from __future__ import annotations

from sagellm_compression.cot.accelerator import CoTAccelerationResult, CoTAccelerator
from sagellm_compression.cot.configs import (
    ChainShorteningConfig,
    CoTAcceleratorConfig,
    CoTStrategyType,
    ParallelChainsConfig,
    PromptCompressionConfig,
)
from sagellm_compression.cot.detector import CoTDetectionResult, CoTDetector
from sagellm_compression.cot.metrics import CoTMetrics
from sagellm_compression.cot.prompt_compressor import (
    CompressionResult,
    HeuristicPromptCompressor,
    PromptCompressor,
)
from sagellm_compression.cot.templates import CoTTemplateManager

__all__ = [
    # Configs
    "CoTAcceleratorConfig",
    "CoTStrategyType",
    "PromptCompressionConfig",
    "ChainShorteningConfig",
    "ParallelChainsConfig",
    # Detector
    "CoTDetector",
    "CoTDetectionResult",
    # Compressor
    "PromptCompressor",
    "HeuristicPromptCompressor",
    "CompressionResult",
    # Accelerator
    "CoTAccelerator",
    "CoTAccelerationResult",
    # Metrics
    "CoTMetrics",
    # Templates
    "CoTTemplateManager",
]



"""Sparsity module for sagellm-compression (Task3.2).

This module provides a sparsification framework including:
- Sparsifier: Applies structured/unstructured sparsity to model weights.
- StubSparsifier: Deterministic CPU-only stub for CI/unit testing.
- SparseWeight / SparseModel: Sparse tensor representations.
- SparsityConfig, UnstructuredSparsityConfig, NMSparsityConfig, BlockSparsityConfig.
"""

from __future__ import annotations

from sagellm_compression.sparsity.configs import (
    BlockSparsityConfig,
    NMSparsityConfig,
    SparsityConfig,
    SparsityType,
    UnstructuredSparsityConfig,
)
from sagellm_compression.sparsity.sparsifier import SparseModel, SparseWeight, Sparsifier
from sagellm_compression.sparsity.stub_sparsifier import StubSparsifier

__all__ = [
    # Configs
    "SparsityConfig",
    "SparsityType",
    "UnstructuredSparsityConfig",
    "NMSparsityConfig",
    "BlockSparsityConfig",
    # Core
    "Sparsifier",
    "StubSparsifier",
    "SparseWeight",
    "SparseModel",
]



"""Quantization module for sagellm-compression (Task3.1).

This module provides quantization framework including:
- Calibrator: Calibrates quantization parameters from sample data
- Quantizer: Performs actual quantization on model weights/activations
- Exporter: Exports quantized models
- Configs: W8A8, W4A16, FP8 quantization configurations
"""

from __future__ import annotations

from sagellm_compression.quantization.calibrator import Calibrator
from sagellm_compression.quantization.configs import (
    FP8Config,
    QuantizationConfig,
    W4A16Config,
    W8A8Config,
)
from sagellm_compression.quantization.exporter import Exporter
from sagellm_compression.quantization.quantizer import Quantizer

__all__ = [
    "Calibrator",
    "Quantizer",
    "Exporter",
    "QuantizationConfig",
    "W8A8Config",
    "W4A16Config",
    "FP8Config",
]
